/*******************************************************************************
* File Name: COMP_YH_1.h  
* Version 1.10
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the Analog Comparitor User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_COMP_COMP_YH_1_H) 
#define CY_COMP_COMP_YH_1_H 

#define COMP_YH_1_RECALMODE 0

/**************************************
*        Function Prototypes 
**************************************/

void    COMP_YH_1_Start(void);
void    COMP_YH_1_Stop(void);
void    COMP_YH_1_SetSpeed(uint8 speed);
uint8   COMP_YH_1_GetCompare(void);
uint8   COMP_YH_1_ZeroCal(void);
void    COMP_YH_1_LoadTrim(uint8 trimVal); 


/**************************************
*           API Constants        
**************************************/
/* Power constants for SetSpeed() function */
#define COMP_YH_1_SLOWSPEED   0x00u
#define COMP_YH_1_HIGHSPEED   0x01u
#define COMP_YH_1_LOWPOWER    0x02u


/**************************************
*           Parameter Defaults        
**************************************/

#define COMP_YH_1_DEFAULT_SPEED       0 
#define COMP_YH_1_DEFAULT_HYSTERESIS  1 
#define COMP_YH_1_DEFAULT_POLARITY    1 
#define COMP_YH_1_DEFAULT_BYPASS_SYNC 1 

/**************************************
*             Registers        
**************************************/

#define COMP_YH_1_CR     (* (reg8 *) COMP_YH_1_ctComp__CR )   /* Config register   */
#define COMP_YH_1_CLK    (* (reg8 *) COMP_YH_1_ctComp__CLK )  /* Comp clock comtrol register */
#define COMP_YH_1_SW0    (* (reg8 *) COMP_YH_1_ctComp__SW0 )  /* Routing registers */
#define COMP_YH_1_SW2    (* (reg8 *) COMP_YH_1_ctComp__SW2 )
#define COMP_YH_1_SW3    (* (reg8 *) COMP_YH_1_ctComp__SW3 )
#define COMP_YH_1_SW4    (* (reg8 *) COMP_YH_1_ctComp__SW4 )
#define COMP_YH_1_SW6    (* (reg8 *) COMP_YH_1_ctComp__SW6 )
#define COMP_YH_1_TR     (* (reg8 *) COMP_YH_1_ctComp__TR )   /* Trim registers */
#define COMP_YH_1_WRK    (* (reg8 *) COMP_YH_1_ctComp__WRK )  /* Working register - output */
#define COMP_YH_1_PWRMGR (* (reg8 *) COMP_YH_1_ctComp__PM_ACT_CFG )  /* Power manager */


/**************************************
*       Register Constants        
**************************************/

/* CR (Comp Control Register)             */
#define COMP_YH_1_CFG_MODE_MASK  0x78u
#define COMP_YH_1_FILTER_ON      0x40u
#define COMP_YH_1_HYST_OFF       0x20u
#define COMP_YH_1_CAL_ON         0x10u
#define COMP_YH_1_MX_AO          0x08u
#define COMP_YH_1_PWRDWN_OVRD    0x04u

#define COMP_YH_1_PWR_MODE_SHIFT 0x00u
#define COMP_YH_1_PWR_MODE_MASK  (0x03u << COMP_YH_1_PWR_MODE_SHIFT)
#define COMP_YH_1_PWR_MODE_SLOW  (0x00u << COMP_YH_1_PWR_MODE_SHIFT)
#define COMP_YH_1_PWR_MODE_FAST  (0x01u << COMP_YH_1_PWR_MODE_SHIFT)
#define COMP_YH_1_PWR_MODE_ULOW  (0x02u << COMP_YH_1_PWR_MODE_SHIFT)

/* CLK (Comp Clock Control Register)      */
#define COMP_YH_1_BYPASS_SYNC    0x10u
#define COMP_YH_1_SYNC_CLK_EN    0x08u
#define COMP_YH_1_SYNCCLK_MASK   (COMP_YH_1_BYPASS_SYNC | COMP_YH_1_SYNC_CLK_EN)

/* SW3Routing Register definitions */
#define COMP_YH_1_CMP_SW3_INPCTL_MASK    0x09u   /* SW3 bits for inP routing control */

/* TR (Comp Trim Register)     */
#define COMP_YH_1_CMP_TRIM1_DIR  0x08u   /* Trim direction for N-type load for offset calibration */
#define COMP_YH_1_CMP_TRIM1_MASK 0x07u   /* Trim for N-type load for offset calibration */
#define COMP_YH_1_CMP_TRIM2_DIR  0x80u   /* Trim direction for P-type load for offset calibration */
#define COMP_YH_1_CMP_TRIM2_MASK 0x70u   /* Trim for P-type load for offset calibration */

/* WRK (Comp output working register)     */ 
#define COMP_YH_1_CMP_OUT_MASK   COMP_YH_1_ctComp__WRK_MASK /* Specific comparator out mask */

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define COMP_YH_1_ACT_PWR_EN     COMP_YH_1_ctComp__PM_ACT_MSK /* Power enable mask */

#endif /* CY_COMP_COMP_YH_1_H */
/* [] END OF FILE  */
