/*******************************************************************************
* File Name: OpAmp_X.c
* Version 1.10
*
* Description:
*   This file provides the source code to the API for the OpAmp (Analog Buffer) 
*   User Module.
*
* NOTE:
* 
*
*******************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/




#include "cytypes.h"
#include "OpAmp_X.h"

uint8  OpAmp_X_initVar = 0;

/*******************************************************************************
* Funciton Name:   OpAmp_X_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values, and 
*  sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters: 
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void OpAmp_X_Start(void) 
{
   if(OpAmp_X_initVar == 0)
   {
      OpAmp_X_initVar = 1;
      OpAmp_X_SetPower(OpAmp_X_DEFAULT_POWER);

      /* Set follower mode if selected */
      OpAmp_X_SW |= OpAmp_X_DEFAULT_MODE;
   }
	
	/*Enable negative charge pumps in ANIF*/
 	OpAmp_X_PUMP_CR1  |= (OpAmp_X_PUMP_CR1_CLKSEL | OpAmp_X_PUMP_CR1_FORCE );
	
	/* Enable power to buffer */
   OpAmp_X_PWRMGR |= OpAmp_X_ACT_PWR_EN;
   
}


/*******************************************************************************
* Function Name: OpAmp_X_Stop
********************************************************************************
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*   (void)
*
* Return:  
*   (void)
*
* Theory: 
*
* Side Effects:
*
*******************************************************************************/
void OpAmp_X_Stop(void)
{
	/*Disable negative charge pumps for ANIF only if the one ABuf is turned ON*/
   	if(OpAmp_X_PWRMGR == OpAmp_X_ACT_PWR_EN)
   	{
	    OpAmp_X_PUMP_CR1 &= ~(OpAmp_X_PUMP_CR1_CLKSEL | OpAmp_X_PUMP_CR1_FORCE );
	}
	
	/* Disable power to buffer */
	OpAmp_X_PWRMGR &= ~OpAmp_X_ACT_PWR_EN;
		
}

/*******************************************************************************
* Funciton Name:   OpAmp_X_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*    power:   Sets power level between low (1) and high power (3).
*
* Return:  
*    (void)
*
* Theory:
*
* Side Effects:
*
**********************************************************************************/
void OpAmp_X_SetPower(uint8 power) 
{
      OpAmp_X_CR &= ~OpAmp_X_PWR_MASK;             /* Clear power setting  */
      OpAmp_X_CR |= ( power & OpAmp_X_PWR_MASK);   /* Set device power     */
}
/* [] END OF FILE */


