/*******************************************************************************
* File Name: Push_nSW.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Push_nSW.h"


/*******************************************************************************
* Function Name: Push_nSW_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void Push_nSW_Write(uint8 value)
{
    uint8 staticBits = Push_nSW_DR & ~Push_nSW_MASK;
    Push_nSW_DR = staticBits | ((value << Push_nSW_SHIFT) & Push_nSW_MASK);
}


/*******************************************************************************
* Function Name: Push_nSW_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void Push_nSW_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(Push_nSW_0, mode);
}


/*******************************************************************************
* Function Name: Push_nSW_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Push_nSW_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Push_nSW_Read(void)
{
    return (Push_nSW_PS & Push_nSW_MASK) >> Push_nSW_SHIFT;
}


/*******************************************************************************
* Function Name: Push_nSW_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Push_nSW_ReadDataReg(void)
{
    return (Push_nSW_DR & Push_nSW_MASK) >> Push_nSW_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Push_nSW_INTSTAT) 

    /*******************************************************************************
    * Function Name: Push_nSW_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Push_nSW_ClearInterrupt(void)
    {
        return (Push_nSW_INTSTAT & Push_nSW_MASK) >> Push_nSW_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
