/*******************************************************************************
* File Name: SPIM.h
* Version 1.20
*
* Description:
* Contains the function prototypes and constants available to the SPI Master
*     user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#define SPIM_DATAWIDTH      16
#define SPIM_InternalClockUsed   1
#define SPIM_InternalInterruptEnabled 0
#define SPIM_ModeUseZero    0

#if(SPIM_InternalClockUsed)
#include "SPIM_IntClock.h"
#endif


#if !defined(CY_SPIM_v1_10_SPIM_H)
#define CY_SPIM_v1_10_SPIM_H

/* Use the Available Enumerated Types */

#if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)     
    #ifdef SPIM_InternalInterrupt__ES2_PATCH      
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (SPIM_InternalInterrupt__ES2_PATCH))      
            #include <intrins.h>        
            #define SPIM_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
        #endif
    #endif
#endif

/***************************************
 *   Function Prototypes
 **************************************/
void  SPIM_Start(void);
void  SPIM_Stop(void);
void  SPIM_EnableInt(void);
void  SPIM_DisableInt(void);
void  SPIM_SetInterruptMode(uint8 intSource);
uint8 SPIM_ReadStatus(void);
void  SPIM_WriteByte(uint16 txDataByte);
uint16 SPIM_ReadByte(void);
/* 8-bit version */
uint8 SPIM_GetRxBufferSize(void);
/* 32-bit version */
//uint16 SPIM_GetRxBufferSize(void);
/* 8-bit version */
uint8  SPIM_GetTxBufferSize(void);
/* 32-bit version */
//uint16  SPIM_GetTxBufferSize(void);
void  SPIM_ClearRxBuffer(void);
void  SPIM_ClearTxBuffer(void);
void  SPIM_TxEnable(void);
void  SPIM_TxDisable(void);
/* 8-bit version */
void  SPIM_PutArray(uint16 *buffer, uint8 byteCount);
/* 32-bit version */
//void SPIM_PutArray(uint32 *buffer, uint16 byteCount);
void SPIM_ClearFIFO(void);

CY_ISR_PROTO(SPIM_ISR);

/***********************************
*     Constants
***********************************/
/* Status Register Definitions */
#define SPIM_STS_SPI_DONE_SHIFT          0x00u     
#define SPIM_STS_TX_FIFO_EMPTY_SHIFT     0x01u
#define SPIM_STS_TX_FIFO_NOT_FULL_SHIFT  0x02u
#define SPIM_STS_RX_FIFO_FULL_SHIFT      0x03u
#define SPIM_STS_RX_FIFO_NOT_EMPTY_SHIFT 0x04u
#define SPIM_STS_RX_FIFO_OVERRUN_SHIFT   0x05u
#define SPIM_STS_BYTE_COMPLETE_SHIFT     0x06u

#define SPIM_STS_SPI_DONE               (0x01u << SPIM_STS_SPI_DONE_SHIFT)        
#define SPIM_STS_TX_FIFO_EMPTY          (0x01u << SPIM_STS_TX_FIFO_EMPTY_SHIFT)    
#define SPIM_STS_TX_FIFO_NOT_FULL       (0x01u << SPIM_STS_TX_FIFO_NOT_FULL_SHIFT)    
#define SPIM_STS_RX_FIFO_FULL           (0x01u << SPIM_STS_RX_FIFO_FULL_SHIFT)    
#define SPIM_STS_RX_FIFO_NOT_EMPTY      (0x01u << SPIM_STS_RX_FIFO_NOT_EMPTY_SHIFT)    
#define SPIM_STS_RX_FIFO_OVERRUN        (0x01u << SPIM_STS_RX_FIFO_OVERRUN_SHIFT)  
#define SPIM_STS_BYTE_COMPLETE          (0x01u << SPIM_STS_BYTE_COMPLETE_SHIFT)

/* StatusI Register Interrupt Enable Control Bits */
#define SPIM_INT_ENABLE                     0x10u   /* As defined by the Register map for the AUX Control Register */

/* Bit Counter (7-bit) Control Register Bit Definitions */
#define SPIM_CNTR_ENABLE                    0x20u   /* As defined by the Register map for the AUX Control Register */
                       
/***************************************
 *    Initialization Values
 **************************************/
#define SPIM_INIT_INTERRUPTS_MASK       (0 << SPIM_STS_SPI_DONE_SHIFT ) | (0 << SPIM_STS_TX_FIFO_NOT_FULL_SHIFT) | (0 << SPIM_STS_TX_FIFO_EMPTY_SHIFT ) | (0 << SPIM_STS_RX_FIFO_NOT_EMPTY_SHIFT ) | (0 << SPIM_STS_RX_FIFO_FULL_SHIFT ) | (0 << SPIM_STS_RX_FIFO_OVERRUN_SHIFT ) | (0 << SPIM_STS_BYTE_COMPLETE_SHIFT) 
#define SPIM_BITCTR_INIT                ((SPIM_DATAWIDTH*2)-1)
/***********************************
*     Parameter values
***********************************/
#define SPIM_TXBUFFERSIZE   1
#define SPIM_RXBUFFERSIZE   1

/********************************
*    Constants
********************************/
/* Datapath Auxillary Control Register definitions */
#define SPIM_AUX_CTRL_FIFO0_CLR         0x01u
#define SPIM_AUX_CTRL_FIFO1_CLR 	    0x02u
#define SPIM_AUX_CTRL_FIFO0_LVL 	    0x04u
#define SPIM_AUX_CTRL_FIFO1_LVL 	    0x08u
#define SPIM_STATUS_ACTL_INT_EN_MASK    0x10u 

/***********************************
*     Registers
***********************************/
#define SPIM_TXDATA             (* (reg16 *)  SPIM_BSPIM_sR16_dp_u0__F0_REG)
#define SPIM_TXDATA_PTR         (  (reg16 *)  SPIM_BSPIM_sR16_dp_u0__F0_REG)
#define SPIM_RXDATA             (* (reg16 *)  SPIM_BSPIM_sR16_dp_u0__F1_REG)
#define SPIM_RXDATA_PTR         (  (reg16 *)  SPIM_BSPIM_sR16_dp_u0__F1_REG)

#define SPIM_AUX_CONTROLDP0	    (* (reg8 *) SPIM_BSPIM_sR16_dp_u0__DP_AUX_CTL_REG)
#define SPIM_AUX_CONTROLDP0_PTR (  (reg8 *) SPIM_BSPIM_sR16_dp_u0__DP_AUX_CTL_REG)
#if (SPIM_DATAWIDTH > 8)
    #define SPIM_AUX_CONTROLDP1	     (* (reg8 *) SPIM_BSPIM_sR16_dp_u1__DP_AUX_CTL_REG)
    #define SPIM_AUX_CONTROLDP1_PTR       ((reg8 *) SPIM_BSPIM_sR16_dp_u1__DP_AUX_CTL_REG)
#endif

#define SPIM_ISR_NUMBER             SPIM_InternalInterrupt__INTC_NUMBER

#define SPIM_ISR_PRIORITY           SPIM_InternalInterrupt__INTC_PRIOR_NUM

#define SPIM_COUNTER_PERIOD    (* (reg8 *)  SPIM_BSPIM_bitCounter__PERIOD_REG)
#define SPIM_COUNTER_CONTROL   (* (reg8 *)  SPIM_BSPIM_bitCounter__CONTROL_AUX_CTL_REG )
#define SPIM_STATUS            (* (reg8 *)  SPIM_BSPIM_stsreg__STATUS_REG)
#define SPIM_STATUS_MASK       (* (reg8 *)  SPIM_BSPIM_stsreg__MASK_REG )
#define SPIM_STATUS_ACTL       (* (reg8 *)  SPIM_BSPIM_stsreg__STATUS_AUX_CTL_REG )
#endif  /* CY_SPIM_v1_10_SPIM_H */
