/*******************************************************************************
* File Name: nPushSW.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "nPushSW.h"


/*******************************************************************************
* Function Name: nPushSW_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void nPushSW_Write(uint8 value)
{
    uint8 staticBits = nPushSW_DR & ~nPushSW_MASK;
    nPushSW_DR = staticBits | ((value << nPushSW_SHIFT) & nPushSW_MASK);
}


/*******************************************************************************
* Function Name: nPushSW_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void nPushSW_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(nPushSW_0, mode);
}


/*******************************************************************************
* Function Name: nPushSW_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro nPushSW_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 nPushSW_Read(void)
{
    return (nPushSW_PS & nPushSW_MASK) >> nPushSW_SHIFT;
}


/*******************************************************************************
* Function Name: nPushSW_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 nPushSW_ReadDataReg(void)
{
    return (nPushSW_DR & nPushSW_MASK) >> nPushSW_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(nPushSW_INTSTAT) 

    /*******************************************************************************
    * Function Name: nPushSW_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 nPushSW_ClearInterrupt(void)
    {
        return (nPushSW_INTSTAT & nPushSW_MASK) >> nPushSW_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
