/*******************************************************************************
* File Name: OneShotX.c  
* Version 1.20
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "OneShotX.h"


/*******************************************************************************
* Function Name: OneShotX_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void OneShotX_Write(uint8 value)
{
    uint8 staticBits = OneShotX_DR & ~OneShotX_MASK;
    OneShotX_DR = staticBits | ((value << OneShotX_SHIFT) & OneShotX_MASK);
}


/*******************************************************************************
* Function Name: OneShotX_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void OneShotX_SetDriveMode(uint8 mode)
{
	CyPins_SetPinDriveMode(OneShotX_0, mode);
}


/*******************************************************************************
* Function Name: OneShotX_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro OneShotX_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 OneShotX_Read(void)
{
    return (OneShotX_PS & OneShotX_MASK) >> OneShotX_SHIFT;
}


/*******************************************************************************
* Function Name: OneShotX_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 OneShotX_ReadDataReg(void)
{
    return (OneShotX_DR & OneShotX_MASK) >> OneShotX_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(OneShotX_INTSTAT) 

    /*******************************************************************************
    * Function Name: OneShotX_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 OneShotX_ClearInterrupt(void)
    {
        return (OneShotX_INTSTAT & OneShotX_MASK) >> OneShotX_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
