/*******************************************************************************
* File Name: SPIM.h
* Version 1.20
*
* Description:
* This file provides all Interrupt Service functionality of the SPI Master component
*
* Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "SPIM.h"

extern uint16 SPIM_RXBUFFER[];
extern uint8 SPIM_RXBUFFERREAD;
extern uint8 SPIM_RXBUFFERWRITE;
extern uint16 SPIM_TXBUFFER[];
extern uint8 SPIM_TXBUFFERREAD;
extern uint8 SPIM_TXBUFFERWRITE;

/*******************************************************************************
* FUNCTION NAME: void SPIM_RXISR( void )
*
* Summary:
* Interrupt Service Routine for RX portion of the UART
*
* Parameters:
* -None-
*
* Return:
* -None-
*
* Theory:
*
* Side Effects:
* -None-
*******************************************************************************/
CY_ISR(SPIM_ISR)
{
   /* User code required at start of ISR */
   /* `#START SPIM_ISR_START` */

   /* `#END` */

   /* 
    * User Module interrupt service code
    */
#if (SPIM_RXBUFFERSIZE > 4) 
    /* See if RX data FIFO has some data and if it can be moved to the RX Buffer */
    while(SPIM_STATUS & SPIM_STS_RX_FIFO_NOT_EMPTY)
    {
        /* Set next pointer. */
        SPIM_RXBUFFERWRITE++;
        if(SPIM_RXBUFFERWRITE >= SPIM_RXBUFFERSIZE)
        {
            SPIM_RXBUFFERWRITE = 0;
        }

        SPIM_RXBUFFER[SPIM_RXBUFFERWRITE] = CY_GET_REG16(SPIM_RXDATA_PTR);
    }
#endif /* SPIM_RXBUFFERSIZE > 4 */
#if (SPIM_TXBUFFERSIZE > 4)  
    /* See if TX data buffer is not empty and there is space in TX FIFO */
    while( (SPIM_TXBUFFERREAD != SPIM_TXBUFFERWRITE) && 
           (SPIM_STATUS & SPIM_STS_TX_FIFO_NOT_FULL))
    {
        SPIM_TXBUFFERREAD++;
    
        if(SPIM_TXBUFFERREAD >= SPIM_TXBUFFERSIZE)
        {
            SPIM_TXBUFFERREAD = 0;
        }
        
        //SPIM_TXDATA = SPIM_TXBUFFER[SPIM_TXBUFFERREAD];
        CY_SET_REG16(SPIM_TXDATA_PTR,SPIM_TXBUFFER[SPIM_TXBUFFERREAD]);
    }
    
    /* Disable Interrupt on TX_fifo_not_empty  if FIFO is empty */
//    if( (SPIM_STATUS & SPIM_STS_TX_FIFO_EMPTY) )
//    {
//        SPIM_STATUS_MASK  &= ~SPIM_STS_TX_FIFO_NOT_FULL; 
//    }

/* Disable Interrupt on TX_fifo_not_empty  if BUFFER is empty */
    if(SPIM_TXBUFFERREAD == SPIM_TXBUFFERWRITE)
    {
        SPIM_STATUS_MASK  &= ~SPIM_STS_TX_FIFO_NOT_FULL; 
    }

#endif /* SPIM_TXBUFFERSIZE > 4 */
   /* User code required at end of ISR (Optional) */
   /* `#START SPIM_ISR_END` */

   /* `#END` */
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD) 
        #ifdef SPIM_InternalInterrupt__ES2_PATCH
            #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (SPIM_InternalInterrupt__ES2_PATCH))              
                SPIM_ISR_PATCH();
            #endif
        #endif
   #endif
}

