/*=========================================
   PSoC5 Sensor Monitor
   2010-07-19
 ========================================*/


#include <device.h>

#define WIND_COMP_PASS_RANGE 15	// Window Comparator Non-trigger range from center
#define USB

/*** Globals ***/
unsigned int x_zeroG, y_zeroG;
unsigned char table[16] = "0123456789ABCDEF"; 
unsigned char strings[32];


void hex_to_4ascii(unsigned int value)
{
	unsigned char temp;
	
	temp = ((value & 0xF000) >> 12);
	strings[0] = table[temp];
	temp = ((value & 0x0F00) >> 8);
	strings[1] = table[temp];	
	temp = ((value & 0x00F0) >> 4);
	strings[2] = table[temp];
	temp = (value & 0x000F);
	strings[3] = table[temp];
}

void clearLCD (void)
{
	LCD_Position(0,0);
	LCD_PrintString("                ");
	LCD_Position(1,0);	
	LCD_PrintString("                ");
}

unsigned int read_temp_sensor(void)
{
	unsigned int spi_read = 0;
	
	SPIM_WriteByte(0x00F0);
	while(!(SPIM_ReadStatus() & SPIM_STS_TX_FIFO_EMPTY)){}  // wait for TX FIFO Empty
	while(!(SPIM_ReadStatus() & SPIM_STS_RX_FIFO_NOT_EMPTY)){} // wait for Rx FIFO
	spi_read = SPIM_ReadByte();
	spi_read = (spi_read >> 4);	// make 10bit data right justified
	spi_read = (spi_read & 0x03FF); // mask 10 bit
	return(spi_read);	
}

void display_temp(unsigned int temp_read)
{
	unsigned char temp_int = 0;
	unsigned char temp_fractional = 0;
	unsigned char negative = 0;

	//check MSB if temperature is negative
	if(temp_read & 0x0200)
	{
		negative = 1;
		temp_read = (~temp_read) +1;
	}
	else negative = 0;
	
	// teke integer portion
	temp_int = (temp_read>>2);   // take integer value
	
	// take fractional portion
	if((temp_read & 0x0003) == 0x0000)temp_fractional = 0x00;
	if((temp_read & 0x0003) == 0x0001)temp_fractional = 0x25;
	if((temp_read & 0x0003) == 0x0002)temp_fractional = 0x50;
	if((temp_read & 0x0003) == 0x0003)temp_fractional = 0x75;

	// Diplay result on LCD
	LCD_Position(0,2);
	if(negative)
	{
		LCD_PutChar(0x2d);
	}
	else{
		LCD_PutChar(0x2b);
	}
	LCD_Position(0,3);
	LCD_PrintNumber(temp_int);
	LCD_Position(0,7);
	LCD_PrintInt8(temp_fractional);		
}

unsigned int read_g_sensor(unsigned char channel)
{
	unsigned int adc_read = 0;
	
	AMux_Select(channel);
	ADC_DelSig_StartConvert();
	ADC_DelSig_IsEndConversion(ADC_DelSig_WAIT_FOR_RESULT);
	adc_read = ADC_DelSig_GetResult16();
	
	return(adc_read);	
}

void calibrateADXL(void)
{
	AMux_Select(0);		// calibrate X sensorZ
	CyDelay(50);
	ADC_DelSig_StartConvert();
	ADC_DelSig_IsEndConversion(ADC_DelSig_WAIT_FOR_RESULT);
	x_zeroG = ADC_DelSig_GetResult16();

	AMux_Select(1);		// calibrate Y sensor
	CyDelay(50);
	ADC_DelSig_StartConvert();
	ADC_DelSig_IsEndConversion(ADC_DelSig_WAIT_FOR_RESULT);
	y_zeroG = ADC_DelSig_GetResult16();
}

void main()
{
	/*** Locals ***/
	unsigned char i;
	unsigned int x_read, y_read, temp_read;
	unsigned char loop_count = 0, usb_timeout;
	unsigned char dac_val_xh, dac_val_xl, dac_val_yh, dac_val_yl;;

	/*** Start UART Component ***/
	UART_Start();
	UART_PutCRLF(0x00);	
	UART_PutString("PSoC5 Sensor Monitor Started");
	UART_PutCRLF(0x00);

	/*** Start LCD Components ***/
	LCD_Start();
	LCD_Position(0,0);
	LCD_PrintString("PSoC5");
	LCD_Position(1,0);
	LCD_PrintString("Sensor Monitor");	
	CyDelay(2000);

	/*** Start USB Components ***/
	clearLCD();
	LCD_Position(0,0);
	LCD_PrintString("Connect USB     ");
	LCD_Position(1,0);
	LCD_PrintString("Push SW to Start");
	while(nPushSW_Read()){} // wait until geting non-zero value by SW pressed down
	CyDelay(100); // Anti chattering
	while(!nPushSW_Read()){} // wait until SW up
	CyDelay(200); // SW delay for to sequre baord boucing due to SW released 
	
	#ifdef USB
	CYGlobalIntEnable;	
	USBUART_Start(0, USBUART_3V_OPERATION);
	usb_timeout = 0;
	loop_count = 0;
	while(!USBUART_bGetConfiguration())
	{
		loop_count++;
		CyDelay(20);
		if(loop_count > 100)
		{
			LCD_Position(1,0);
			LCD_PrintString("timeout!        ");
			usb_timeout = 1;
			break;
		}
	}
	if(usb_timeout == 0)
	{
		USBUART_Init();
		LCD_Position(1,0);
		LCD_PrintString("connected!      ");
	}
	CyDelay(2000);	
	#endif
	
	/*** Start Opamp Coponents ***/
	OpAmp_X_Start();
	OpAmp_Y_Start();

	/*** Start COMP ***/
	COMP_XH_Start();
	COMP_XL_Start();
	COMP_YH_Start();
	COMP_YL_Start();
	
	/*** Start DAC Components ***/
	VDAC8_XH_Start();
	VDAC8_XL_Start();
	VDAC8_YH_Start();
	VDAC8_YL_Start();
		
	/*** VDAC Debug ***/
	//VDAC8_YH_SetValue(110);		// set final VDAC voltage	
	//VDAC8_YL_SetValue(110);		// set final VDAC voltage	
	//VDAC8_XL_SetValue(110);		// set final VDAC voltage
	//i = 0;
	//while(1)
	//{
	//	VDAC8_XH_SetValue(i);		// set final VDAC voltage
	//	i++;
	//	CyDelay(5);
	//}
		
	/*** Start ADC/AMUX/SPI Components ***/
	AMux_Start();
	ADC_DelSig_Start();
	SPIM_Start();

	/*** Start Sensor Calibration ***/
	LCD_Position(0,0);
	LCD_PrintString("Push SW to Start");
	LCD_Position(1,0);	
	LCD_PrintString("ADXL Calibration");
	while(nPushSW_Read()){} // wait until geting non-zero value by SW pressed down
	CyDelay(100); // Anti chattering
	while(!nPushSW_Read()){} // wait until SW up
	CyDelay(200); // SW delay for to sequre baord boucing due to SW released 
	calibrateADXL();
	LCD_Position(0,0);
	LCD_PrintString("Calibration     ");
	LCD_Position(1,0);	
	LCD_PrintString("Completed!      ");	
	CyDelay(2000);
	LCD_Position(0,0);
	LCD_PrintString("X=              ");
	LCD_Position(1,0);	
	LCD_PrintString("Y=              ");
	LCD_Position(0,2); // x location
	LCD_PrintHexUint16(x_zeroG);	
	LCD_Position(1,2); // y location
	LCD_PrintHexUint16(y_zeroG);
	CyDelay(2000);
	clearLCD();

	/*** Find DAC value for XH ***/
	dac_val_xh = 0xFF;
	VDAC8_XH_SetValue(dac_val_xh);
	CyDelay(2);
	while(COMP_XH_GetCompare())         // non-zero retuned if pos input is higher than neg input
	{
		dac_val_xh--;
		VDAC8_XH_SetValue(dac_val_xh);	// decrease VDAC voltage
		CyDelay(2);
	}
	dac_val_xh += WIND_COMP_PASS_RANGE;
	VDAC8_XH_SetValue(dac_val_xh);		// set final VDAC voltage
	
	/*** Find DAC value for XL ***/
	dac_val_xl = 0x00;
	VDAC8_XL_SetValue(dac_val_xl);
	CyDelay(2);
	while(COMP_XL_GetCompare())         // non-zero retuned if pos input is higher than neg input
	{
		dac_val_xl++;
		VDAC8_XL_SetValue(dac_val_xl);	// increase VDAC voltage
		CyDelay(2);
	}
	dac_val_xl -= WIND_COMP_PASS_RANGE;
	VDAC8_XL_SetValue(dac_val_xl);		// set final VDAC voltage

	/*** Find DAC value for YH ***/
	dac_val_yh = 0xFF;
	VDAC8_YH_SetValue(dac_val_yh);
	CyDelay(2);
	while(COMP_YH_GetCompare())    		// non-zero retuned if pos input is higher than neg input
	{
		dac_val_yh--;
		VDAC8_YH_SetValue(dac_val_yh);	 // decrease VDAC voltage
		CyDelay(2);
	}
	dac_val_yh += WIND_COMP_PASS_RANGE;
	VDAC8_YH_SetValue(dac_val_yh);		// set final VDAC voltage
	
	/*** Find DAC value for YL ***/
	dac_val_yl = 0x00;
	CyDelay(2);
	VDAC8_YL_SetValue(dac_val_yl);
	while(COMP_YL_GetCompare())    		// non-zero retuned if pos input is higher than neg input
	{
		dac_val_yl++;
		VDAC8_YL_SetValue(dac_val_yl);	// increase VDAC voltage
		CyDelay(2);
	}
	dac_val_yl -= WIND_COMP_PASS_RANGE;
	VDAC8_YL_SetValue(dac_val_yl);		// set final VDAC voltage	

	LCD_Position(0,0);
	LCD_PrintString("VDAC Auto Cal   ");
	LCD_Position(1,0);	
	LCD_PrintString("Completed!      ");	
	CyDelay(2000);
	clearLCD();

	/*** Setup LCD for monitor loop ***/
	LCD_Position(0,0);
	LCD_PrintString("T:    .   degC");
	LCD_Position(1,0);
	LCD_PrintString("X:      Y:    ");

    while(1)
    {
		/*** Step1: Read X Sensor ***/
		x_read = read_g_sensor(1);
		LCD_Position(1,2); // x location
		LCD_PrintHexUint16(x_read);
		hex_to_4ascii(x_read);
		strings[4] = 0x2C;		
		USBUART_Write(strings, 5);
		
		/*** Step2: Read Y Sensor ***/
		y_read = read_g_sensor(0);
		LCD_Position(1,10);// y location
		LCD_PrintHexUint16(y_read);
		hex_to_4ascii(y_read);
		strings[4] = 0x2C;
		USBUART_Write(strings, 5);		
		
		/*** Step3: Read Temp Sensor ***/
		temp_read = read_temp_sensor();
		display_temp(temp_read);		
		hex_to_4ascii(temp_read);
		strings[4] = 0x0D;
		strings[5] = 0x0A;
		CyDelay(10);
		USBUART_Write(strings, 6);		

		/*** SW Delay ***/
		CyDelay(500);		
    }
}

/* [] END OF FILE */
